# geomeppyupdated

This is an updated version of Geomeppy with limited modifications. Really the main issue that has been addressed is the change of import in `geom/polygons.py`. The import of `MutableSequence` must now come from `collections.abc`.

========

## Referencing

Please reference the original author if you use this package:

If you rely on this package in academic work, and would like to include a citation (which we greatly appreciate), please refer to this project as:

- Bull J, et al. GeomEppy, 2016-, <<https://github.com/jamiebull1/geom>
